@@ -41,15 +41,9 @@ def clone(repo: str):
     with open(path.join(project_dir, repo_name, ".worktree"), "w") as f:
         f.write("")
 
-# @click.option(
-#     "-p",
-#     "--project",
-#     "project",
-#     type=ProjectType(),
-#     help="project name",
-# )
 @cli.command(help="checkout a new branch")
 @click.argument("branch", required=True)
+@click.argument("project", required=False)
 def checkout(branch: str, project: Optional[str]):
     config = load_config()
     worktree_root = find_worktree_root()
